==> qtjambi-dbus-debuginfo-windows-x64-6.6.0.jar: sources/QtJambiDBus/QDBusVirtualObject_shell.h <==
#ifndef QDBUSVIRTUALOBJECT_SHELL_H
#define QDBUSVIRTUALOBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDBus/qdbusvirtualobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtDBus/qdbusconnection.h>
#include <QtDBus/qdbusmessage.h>
#include <QtJambi/RegistryAPI>


class QDBusVirtualObject_shell : public QDBusVirtualObject, public QtJambiShellInterface
{
public:
    QDBusVirtualObject_shell(QObject* parent0 = nullptr);
    ~QDBusVirtualObject_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool handleMessage(const QDBusMessage& message0, const QDBusConnection& connection1) override;
    QString introspect(const QString& path0) const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDBusVirtualObject_access : public QDBusVirtualObject
{
    jboolean __qt_handleMessage_cref_QDBusMessage_cref_QDBusConnection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID message0, QtJambiNativeID connection1);
    jstring __qt_introspect_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring path0) const;
};

#endif // QDBUSVIRTUALOBJECT_SHELL_H

==> qtjambi-dbus-debuginfo-windows-x64-6.7.1.jar: sources/QtJambiDBus/QDBusVirtualObject_shell.h <==
#ifndef QDBUSVIRTUALOBJECT_SHELL_H
#define QDBUSVIRTUALOBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDBus/qdbusvirtualobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtDBus/qdbusconnection.h>
#include <QtDBus/qdbusmessage.h>
#include <QtJambi/RegistryAPI>


class QDBusVirtualObject_shell : public QDBusVirtualObject, public QtJambiShellInterface
{
public:
    QDBusVirtualObject_shell(QObject* parent0 = nullptr);
    ~QDBusVirtualObject_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QDBusVirtualObject_mshell;
    friend class QDBusVirtualObject_oshell;
};


class QDBusVirtualObject_mshell : public QDBusVirtualObject_shell
{
public:
    using QDBusVirtualObject_shell::QDBusVirtualObject_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QDBusVirtualObject_oshell : public QDBusVirtualObject_mshell
{
public:
    using QDBusVirtualObject_mshell::QDBusVirtualObject_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool handleMessage(const QDBusMessage& message0, const QDBusConnection& connection1) override;
    QString introspect(const QString& path0) const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDBusVirtualObject_access : public QDBusVirtualObject
{
    jboolean __qt_handleMessage_cref_QDBusMessage_cref_QDBusConnection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID message0, QtJambiNativeID connection1);
    jstring __qt_introspect_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring path0) const;
};

#endif // QDBUSVIRTUALOBJECT_SHELL_H
